NLSL: parsav Module Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- Modules List
- Module Members

Variables
parsav Module Reference

## Variables
double precision, dimension(6, mxvar), save | fxsave
double precision, dimension(nfprm, mxsite), save | fprsav
double precision, dimension(4, mxspc), save | spsave
integer, dimension(3, mxvar), save | ixsave
integer, dimension(niprm, mxsite), save | iprsav
integer, dimension(nfprm, mxsite), save | ixxsav
integer, save | nstsav
integer, save | nspsav
integer, save | nprsav
logical, save | xsaved
logical, save | prsaved
character *9, dimension(mxvar), save | tagsav

## Variable Documentation

double precision, dimension(nfprm,mxsite), save parsav::fprsav

Definition at line 17 of file parsav.f90.

double precision, dimension(6,mxvar), save parsav::fxsave

Definition at line 17 of file parsav.f90.

integer, dimension(niprm,mxsite), save parsav::iprsav

Definition at line 20 of file parsav.f90.

integer, dimension(3,mxvar), save parsav::ixsave

Definition at line 20 of file parsav.f90.

integer, dimension(nfprm,mxsite), save parsav::ixxsav

Definition at line 20 of file parsav.f90.

integer, save parsav::nprsav

Definition at line 20 of file parsav.f90.

integer, save parsav::nspsav

Definition at line 20 of file parsav.f90.

integer, save parsav::nstsav

Definition at line 20 of file parsav.f90.

logical, save parsav::prsaved

Definition at line 23 of file parsav.f90.

double precision, dimension(4,mxspc), save parsav::spsave

Definition at line 17 of file parsav.f90.

character*9, dimension(mxvar), save parsav::tagsav

Definition at line 25 of file parsav.f90.

logical, save parsav::xsaved

Definition at line 23 of file parsav.f90.